<template>
  <Popover
    v-if="!hideButton"
    class="relative"
  >
    <PopoverButton class="btn btn-outline-primary">
      <ButtonIcon :icon="FilterRegularIcon">
        {{ $t("app.filters.button") }}
      </ButtonIcon>
    </PopoverButton>
    <transition
      enter-active-class="transition ease-out duration-200"
      enter-from-class="opacity-0"
      enter-to-class="opacity-100"
      leave-active-class="transition ease-in duration-150"
      leave-from-class="opacity-100"
      leave-to-class="opacity-0"
    >
      <PopoverPanel
        :unmount="false"
        class="absolute right-0 z-10 mt-2 w-72 rounded-md border border-gray-900/10 bg-white shadow md:w-80"
      >
        <div class="flex items-center justify-between border-b border-gray-900/10 px-4 py-2">
          <div class="my-auto text-base font-medium text-gray-900">
            {{ $t("app.filters.button") }}
          </div>
          <div>
            <button
              class="btn btn-white"
              type="button"
              @click.prevent="$emit('clear')"
            >
              {{ $t("app.filters.clear") }}
            </button>
          </div>
        </div>
        <div class="flex flex-col gap-4 px-4 pb-4 pt-2">
          <slot />
        </div>
      </PopoverPanel>
    </transition>
  </Popover>
</template>

<script generic="T" lang="ts" setup>
import FilterRegularIcon from "@/svg/icons/filter-regular.svg?component";
import { Popover, PopoverButton, PopoverPanel } from "@headlessui/vue";
import ButtonIcon from "@/js/contexts/shared/ui/components/button/ButtonIcon.vue";

const props = defineProps<{
  modelValue: T;
  hideButton?: boolean;
}>();

const emit = defineEmits<{
  clear: [];
  updated: [];
}>();

watch(
  () => props.modelValue,
  () => emit("updated"),
  { deep: true },
);
</script>
